===========
Change logs
===========

v0.1.0
======

:date: 2023-10-22

No feature updates

Misc
----

* Deploy document to readthedocs.

v0.1.1
======

:date: 2023-10-21

First release.

Features
--------

* Small extension to override behavior of code-block and literalinclude.
